# IEEE Std. 1685-2009

Source: http://www.accellera.org/XMLSchema/SPIRIT/1685-2009/


From the Accellera page
-----------------------

© Copyright Accellera Systems Initiative. All rights reserved.

These XML files are believed to be a consistent XML Schema expression for creating and validating XML documents based on
the IEEE Std 1685-2009 Standard for IP-XACT, Standard Structure for Packaging, Integrating and Re-using IP within
Tool-flows. These files are in the format specified by the World Wide Web Consortium (W3C) as XML Schema definition
language.

The purpose of this schema is to allow the creation and validation of XML documents conforming to the IEEE Std 1685-2009
Standard for IP-XACT, Standard Structure for Packaging, Integrating and Re-using IP within Tool-flows.

**USE AT YOUR OWN RISK**

These source files are provided on an AS IS basis.  Accellera Systems Initiative disclaims any warranty express or
implied including any warranty of merchantability and fitness for use for a particular purpose.

The user of the source files shall indemnify and hold Accellera Systems Initiative and its members harmless from any
damages or liability.

This file may be copied, and distributed, WITHOUT modifications; this notice must be included on any copy.

This schema shall not be modified, adapted, altered, sublicensed, nor any derivative works shall be created based upon
the schema.  The intended and allowed uses of the schema include:

* Creating and validating XML documents that conform to the schema
* Building software programs and systems based on the schema
* Distributing verbatim copy of the schema as long as the full text of this license is included in all copies of the
  schema. Specifically, a tool may include full copies of the schema, and these copies may be distributed by the tool
  provider directly.  A link or URL to the original of the schema is inherent in the schema URI.
* Documents which are validated against this schema may also reference additional schema. These additional schemas may
  provide for validation of elements and attributes at the extension points explicitly and implicitly included in the
  IEEE 1685-2009 standard.
* No right to create new schemas derived from parts of this base schema is granted pursuant to this License.
